@@ -5,7 +5,6 @@ from contextlib import contextmanager
 import curses
 from curses import setupterm, tigetnum, tigetstr, tparm
 from fcntl import ioctl
-import collections
 
 try:
     from io import UnsupportedOperation as IOUnsupportedOperation
@@ -80,7 +79,7 @@ class Terminal(object):
             stream = sys.__stdout__
         try:
             stream_descriptor = (stream.fileno() if hasattr(stream, 'fileno')
-                                 and isinstance(stream.fileno, collections.Callable)
+                                 and callable(stream.fileno)
                                  else None)
         except IOUnsupportedOperation:
             stream_descriptor = None
